<?php

namespace DsbNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util;
use Teknisa\Libs\Util\NewCode;

class ParametersDashboardController {
    protected $crudService;
    protected $newCode;
    protected $service;
  
    public function __construct($connection, $environment, $util, $crudService, $newCode, $service) {
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->util         = $util;
        $this->crudService	= $crudService;
        $this->newCode	    = $newCode;
        $this->service      = $service;
    }
  
    public function addProfileAccess(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
          
            $nrperfaclpainel = intval($this->newCode->getCodeByTableName("PERFACLPAINEL", $this->environment->getNrOrgTrab()));
            $params = [
                "NRPERFACLPAINEL" => $nrperfaclpainel,
                "NRPAINEL" => $row["NRPAINEL"],
                "NRPERFILACESSO" => $row["NRPERFILACESSO"],
                "CDFILIAL" => $row["CDFILIAL"],
                "IDPADRAODASH" => $row["IDPADRAODASH"],
                "NRORG" => $this->environment->getNrorg()
            ];
           $this->service->insertProfile($params);
          
           $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function dellProfileAccess(Request\DataSet $request, Response $response) {
        $rows = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($rows["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"]
                ];
                $this->service->deleteProfileAccess($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function rowsProfileUpdate(Request\DataSet $request, Response $response) {
        $rows = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($rows["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
                    "IDPADRAODASH" => $row["IDPADRAODASH"],
                    "CDFILIAL" => $row["CDFILIAL"]
                ];
                $this->service->rowsProfileUpdate($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function rowsUpdateIndicator(Request\Row $request, Response $response) {
        $rows = $request->getRow();
        try{
            $this->service->beginTransaction();
            foreach($rows['INDICATOR'] as $row){
                if(!isset($row['NRINDICPAINEL'])){
                    $nrindicpainel = intval($this->newCode->getCodeByTableName("INDICPAINEL", $this->environment->getNrOrgTrab()));
                    $params = [
                        "NRINDICPAINEL" => $nrindicpainel,
                        "NRPERFACLPAINEL" => intval($row['NRPERFACLPAINEL']),
                        "NRINDICADORTF" => $row["NRINDICADORTF"],
                        "IDVISUINDIC" => $row["IDVISUINDIC"],
                        "NRORG" => $this->environment->getNrorg()
                    ];
                    $this->service->insertIndicpanel($params);
                }else{
                    $params = [
                        "NRINDICPAINEL" => $row["NRINDICPAINEL"],
                        "IDVISUINDIC" => $row["IDVISUINDIC"],
                        "NRORG" => $this->environment->getNrorg()
                    ];
                    $this->service->updateIndicpanel($params);
                }
            }
            $this->service->commit();
		}catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
}